import { getZeplinLinkProperties, RESOURCE_TYPES } from "@zeplin/storybook-inspector";
import { Configuration, ZeplinApi } from "@zeplin/sdk";
import { ZEPLIN_TOKEN, ZEPLIN_API_URL, ZEPLIN_WEB_BASE, ZEPLIN_APP_BASE } from "../constants";
const ZEPLIN_TOKEN_STORAGE_KEY = "storybook_zeplin:access_token";
let cachedUser;
const zeplinCache = new Map();
function getZeplinToken() {
    return localStorage.getItem(ZEPLIN_TOKEN_STORAGE_KEY) || ZEPLIN_TOKEN;
}
const zeplinApi = new ZeplinApi(new Configuration({
    accessToken: getZeplinToken
}), ZEPLIN_API_URL);
export function isLoggedIn() {
    return Boolean(getZeplinToken());
}
export function login(token) {
    localStorage.setItem(ZEPLIN_TOKEN_STORAGE_KEY, token);
}
export function logout() {
    localStorage.removeItem(ZEPLIN_TOKEN_STORAGE_KEY);
    cachedUser = undefined;
    zeplinCache.clear();
}
export async function getZeplinResource(zeplinLink) {
    var _a, _b;
    const cachedValue = zeplinCache.get(zeplinLink);
    if (cachedValue) {
        return cachedValue;
    }
    const linkProperties = getZeplinLinkProperties(zeplinLink, {
        web: ZEPLIN_WEB_BASE,
        app: ZEPLIN_APP_BASE
    });
    try {
        switch (linkProperties.type) {
            case RESOURCE_TYPES.PROJECT_COMPONENT: {
                const { data } = await zeplinApi.components.getProjectComponent(linkProperties.pid, linkProperties.coid);
                zeplinCache.set(zeplinLink, data);
                return data;
            }
            case RESOURCE_TYPES.STYLEGUIDE_COMPONENT: {
                const { data } = await zeplinApi.components.getStyleguideComponent(linkProperties.stid, linkProperties.coid);
                zeplinCache.set(zeplinLink, data);
                return data;
            }
            case RESOURCE_TYPES.SCREEN: {
                const { data } = await zeplinApi.screens.getScreen(linkProperties.pid, linkProperties.sid);
                zeplinCache.set(zeplinLink, data);
                return data;
            }
            default:
                return {
                    error: "Zeplin link is invalid.",
                };
        }
    }
    catch (e) {
        return {
            error: ((_b = (_a = e.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) || e.message,
        };
    }
}
export async function getUser() {
    var _a, _b;
    if (cachedUser) {
        return cachedUser;
    }
    try {
        const { data } = await zeplinApi.users.getCurrentUser();
        cachedUser = data;
        return data;
    }
    catch (e) {
        return {
            error: ((_b = (_a = e.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) || e.message,
        };
    }
}
